summaryrefslogtreecommitdiff
path: root/test/fixedbugs/bug197.go
diff options
context:
space:
mode:
authorIan Lance Taylor <iant@golang.org>2009-08-31 21:39:08 -0700
committerIan Lance Taylor <iant@golang.org>2009-08-31 21:39:08 -0700
commit83304f4eacc83127b6feecb0254a07aa47dea074 (patch)
treed80d39fbb611197fe89697259fb1becb4458284f /test/fixedbugs/bug197.go
parentd0e6d855d3e867d501ff1ae62abb43cef6eb7a11 (diff)
downloadgo-83304f4eacc83127b6feecb0254a07aa47dea074.tar.gz
Match gccgo error messages.
bug197.go:10:5: error: incompatible type in initialization bug197.go:11:5: error: incompatible type in initialization bug197.go:12:5: error: incompatible type in initialization bug197.go:13:5: error: incompatible type in initialization bug197.go:20:13: error: incompatible types in binary expression bug197.go:21:27: error: incompatible types in binary expression R=rsc DELTA=6 (0 added, 0 deleted, 6 changed) OCL=34135 CL=34177
Diffstat (limited to 'test/fixedbugs/bug197.go')
-rw-r--r--test/fixedbugs/bug197.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/fixedbugs/bug197.go b/test/fixedbugs/bug197.go
index 501b94ce0..c205c5bca 100644
--- a/test/fixedbugs/bug197.go
+++ b/test/fixedbugs/bug197.go
@@ -11,18 +11,18 @@ type U int
var x int
-var t T = int(0) // ERROR "cannot use"
-var t1 T = int(x) // ERROR "cannot use"
-var u U = int(0) // ERROR "cannot use"
-var u1 U = int(x) // ERROR "cannot use"
+var t T = int(0) // ERROR "cannot use|incompatible"
+var t1 T = int(x) // ERROR "cannot use|incompatible"
+var u U = int(0) // ERROR "cannot use|incompatible"
+var u1 U = int(x) // ERROR "cannot use|incompatible"
type S string
var s S
var s1 = s + "hello"
var s2 = "hello" + s
-var s3 = s + string("hello") // ERROR "invalid operation"
-var s4 = string("hello") + s // ERROR "invalid operation"
+var s3 = s + string("hello") // ERROR "invalid operation|incompatible"
+var s4 = string("hello") + s // ERROR "invalid operation|incompatible"
var r string